summaryrefslogtreecommitdiffstats
path: root/kwordquiz/src/kwordquizview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kwordquiz/src/kwordquizview.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwordquiz/src/kwordquizview.h')
-rw-r--r--kwordquiz/src/kwordquizview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kwordquiz/src/kwordquizview.h b/kwordquiz/src/kwordquizview.h
index 9c4a3f0d..b49ea65c 100644
--- a/kwordquiz/src/kwordquizview.h
+++ b/kwordquiz/src/kwordquizview.h
@@ -54,11 +54,11 @@ class KWordQuizView : public TQTable
TQ_OBJECT
public:
/** Constructor for the main view */
- KWordQuizView(TQWidget *tqparent = 0, const char *name=0);
+ KWordQuizView(TQWidget *parent = 0, const char *name=0);
/** Destructor for the main view */
~KWordQuizView();
/** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a tqparent
* widget to get to the window document pointer by calling the KWordQuizApp::getDocument() method.
*
* @see KWordQuizApp#getDocument
@@ -54,11 +54,11 @@ class KWordQuizView : public TQTable
/** Destructor for the main view */
~KWordQuizView();
- /** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a tqparent
+ /** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a parent
* widget to get to the window document pointer by calling the KWordQuizApp::getDocument() method.
*